@@ -24,6 +24,7 @@
 #include <QClipboard>
 #include <QPointer>
 #include <QDebug>
+#include <QX11Info>
 
 struct RfbServer::Private
 {
@@ -108,7 +109,7 @@ bool RfbServer::start()
     }
 
     if (listeningAddress() != "0.0.0.0") {
-        strncpy(d->screen->thisHost, listeningAddress().data(), 254);
+        strncpy(d->screen->thisHost, listeningAddress().constData(), 254);
     }
 
     if (listeningPort() == 0) {
@@ -143,8 +144,11 @@ bool RfbServer::start()
         d->ipv6notifier = new QSocketNotifier(d->screen->listen6Sock, QSocketNotifier::Read, this);
         connect(d->ipv6notifier, &QSocketNotifier::activated, this, &RfbServer::onListenSocketActivated);
     }
-    connect(QApplication::clipboard(), &QClipboard::dataChanged,
-            this, &RfbServer::krfbSendServerCutText);
+
+    if (QX11Info::isPlatformX11()) {
+        connect(QApplication::clipboard(), &QClipboard::dataChanged,
+                this, &RfbServer::krfbSendServerCutText);
+    }
 
     return true;
 }
@@ -162,6 +166,17 @@ void RfbServer::stop()
     }
 }
 
+void RfbServer::updateFrameBuffer(char *fb, int width, int height, int depth)
+{
+    int bpp = depth >> 3;
+
+    if (bpp != 1 && bpp != 2 && bpp != 4) {
+        bpp = 4;
+    }
+
+    rfbNewFramebuffer(d->screen, fb, width, height, 8, 3, bpp);
+}
+
 void RfbServer::updateScreen(const QList<QRect> & modifiedTiles)
 {
     if (d->screen) {
